@@ -1228,8 +1228,12 @@ class Builder(Update):
             content.append(entry)
         fn_grubcfg = path.join(dn, 'grub.cfg')
         try:
-            with writeFile(fn_grubcfg) as f:
-                f.write(("\n".join(content)).strip()+"\n")
+            write_content = ("\n".join(content)).strip()+"\n"
+            if write_content.strip():
+                with writeFile(fn_grubcfg) as f:
+                    f.write(write_content)
+            else:
+                self.clear_iso_grub_cfg(dn)
         except IOError:
             raise BuilderError(_("Failed to write %s") % fn_grubcfg)
         return True
