@@ -213,7 +213,7 @@ class Wsdl(WsdlBase):
             # метод присутствует в графической консоли
             'gui': True,
             # консольная команда
-            'command': 'cl-update-livemenu',
+            'command': 'cl-update-boot-live',
             # права для запуска метода
             'rights': ['build'],
             # объект содержащий модули для действия
